==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_entities/workorderschedule_002/WorkOrderSchedule.java <==

package net.datastream.schemas.mp_entities.workorderschedule_002;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CREWID_Type;
import net.datastream.schemas.mp_fields.DEPARTMENTID_Type;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.PERSONID_Type;
import net.datastream.schemas.mp_fields.SHIFTID_Type;
import net.datastream.schemas.mp_fields.TIME_Type;
import net.datastream.schemas.mp_fields.TRADEID_Type;
import net.datastream.schemas.mp_fields.WOSCHEDULEID;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WOSCHEDULEID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SCHEDULEDDATE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SCHEDULEDHOURS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTUALSTARTTIME" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTUALENDTIME" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRADEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SHIFTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EMPLOYEE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CREWID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MAINTENANCEEQUIPMENTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ENTEREDBY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROZEN" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WOSCHEDULECOMMENT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DBSESSIONID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}MAINRESOURCE" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "woscheduleid",
    "scheduleddate",
    "scheduledhours",
    "actualstarttime",
    "actualendtime",
    "tradeid",
    "departmentid",
    "shiftid",
    "employee",
    "crewid",
    "maintenanceequipmentid",
    "enteredby",
    "frozen",
    "woschedulecomment",
    "dbsessionid",
    "mainresource"
})
@XmlRootElement(name = "WorkOrderSchedule")
public class WorkOrderSchedule {

    @XmlElement(name = "WOSCHEDULEID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected WOSCHEDULEID woscheduleid;
    @XmlElement(name = "SCHEDULEDDATE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected DATETIME scheduleddate;
    @XmlElement(name = "SCHEDULEDHOURS", namespace = "http://schemas.datastream.net/MP_fields")
    protected Double scheduledhours;
    @XmlElement(name = "ACTUALSTARTTIME", namespace = "http://schemas.datastream.net/MP_fields")
    protected TIME_Type actualstarttime;
    @XmlElement(name = "ACTUALENDTIME", namespace = "http://schemas.datastream.net/MP_fields")
    protected TIME_Type actualendtime;
    @XmlElement(name = "TRADEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected TRADEID_Type tradeid;
    @XmlElement(name = "DEPARTMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "SHIFTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected SHIFTID_Type shiftid;
    @XmlElement(name = "EMPLOYEE", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERSONID_Type employee;
    @XmlElement(name = "CREWID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CREWID_Type crewid;
    @XmlElement(name = "MAINTENANCEEQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTID_Type maintenanceequipmentid;
    @XmlElement(name = "ENTEREDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected String enteredby;
    @XmlElement(name = "FROZEN", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "-")
    protected String frozen;
    @XmlElement(name = "WOSCHEDULECOMMENT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String woschedulecomment;
    @XmlElement(name = "DBSESSIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY dbsessionid;
    @XmlElement(name = "MAINRESOURCE", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String mainresource;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Obtient la valeur de la propriété woscheduleid.
     * 
     * @return
     *     possible object is
     *     {@link WOSCHEDULEID }
     *     
     */
    public WOSCHEDULEID getWOSCHEDULEID() {
        return woscheduleid;
    }

    /**
     * Définit la valeur de la propriété woscheduleid.
     * 
     * @param value
     *     allowed object is
     *     {@link WOSCHEDULEID }
     *     
     */
    public void setWOSCHEDULEID(WOSCHEDULEID value) {
        this.woscheduleid = value;
    }

    /**
     * Obtient la valeur de la propriété scheduleddate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSCHEDULEDDATE() {
        return scheduleddate;
    }

    /**
     * Définit la valeur de la propriété scheduleddate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSCHEDULEDDATE(DATETIME value) {
        this.scheduleddate = value;
    }

    /**
     * Obtient la valeur de la propriété scheduledhours.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getSCHEDULEDHOURS() {
        return scheduledhours;
    }

    /**
     * Définit la valeur de la propriété scheduledhours.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setSCHEDULEDHOURS(Double value) {
        this.scheduledhours = value;
    }

    /**
     * Obtient la valeur de la propriété actualstarttime.
     * 
     * @return
     *     possible object is
     *     {@link TIME_Type }
     *     
     */
    public TIME_Type getACTUALSTARTTIME() {
        return actualstarttime;
    }

    /**
     * Définit la valeur de la propriété actualstarttime.
     * 
     * @param value
     *     allowed object is
     *     {@link TIME_Type }
     *     
     */
    public void setACTUALSTARTTIME(TIME_Type value) {
        this.actualstarttime = value;
    }

    /**
     * Obtient la valeur de la propriété actualendtime.
     * 
     * @return
     *     possible object is
     *     {@link TIME_Type }
     *     
     */
    public TIME_Type getACTUALENDTIME() {
        return actualendtime;
    }

    /**
     * Définit la valeur de la propriété actualendtime.
     * 
     * @param value
     *     allowed object is
     *     {@link TIME_Type }
     *     
     */
    public void setACTUALENDTIME(TIME_Type value) {
        this.actualendtime = value;
    }

    /**
     * Obtient la valeur de la propriété tradeid.
     * 
     * @return
     *     possible object is
     *     {@link TRADEID_Type }
     *     
     */
    public TRADEID_Type getTRADEID() {
        return tradeid;
    }

    /**
     * Définit la valeur de la propriété tradeid.
     * 
     * @param value
     *     allowed object is
     *     {@link TRADEID_Type }
     *     
     */
    public void setTRADEID(TRADEID_Type value) {
        this.tradeid = value;
    }

    /**
     * Obtient la valeur de la propriété departmentid.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Définit la valeur de la propriété departmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Obtient la valeur de la propriété shiftid.
     * 
     * @return
     *     possible object is
     *     {@link SHIFTID_Type }
     *     
     */
    public SHIFTID_Type getSHIFTID() {
        return shiftid;
    }

    /**
     * Définit la valeur de la propriété shiftid.
     * 
     * @param value
     *     allowed object is
     *     {@link SHIFTID_Type }
     *     
     */
    public void setSHIFTID(SHIFTID_Type value) {
        this.shiftid = value;
    }

    /**
     * Obtient la valeur de la propriété employee.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getEMPLOYEE() {
        return employee;
    }

    /**
     * Définit la valeur de la propriété employee.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setEMPLOYEE(PERSONID_Type value) {
        this.employee = value;
    }

    /**
     * Obtient la valeur de la propriété crewid.
     * 
     * @return
     *     possible object is
     *     {@link CREWID_Type }
     *     
     */
    public CREWID_Type getCREWID() {
        return crewid;
    }

    /**
     * Définit la valeur de la propriété crewid.
     * 
     * @param value
     *     allowed object is
     *     {@link CREWID_Type }
     *     
     */
    public void setCREWID(CREWID_Type value) {
        this.crewid = value;
    }

    /**
     * Obtient la valeur de la propriété maintenanceequipmentid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getMAINTENANCEEQUIPMENTID() {
        return maintenanceequipmentid;
    }

    /**
     * Définit la valeur de la propriété maintenanceequipmentid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setMAINTENANCEEQUIPMENTID(EQUIPMENTID_Type value) {
        this.maintenanceequipmentid = value;
    }

    /**
     * Obtient la valeur de la propriété enteredby.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENTEREDBY() {
        return enteredby;
    }

    /**
     * Définit la valeur de la propriété enteredby.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENTEREDBY(String value) {
        this.enteredby = value;
    }

    /**
     * Obtient la valeur de la propriété frozen.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFROZEN() {
        return frozen;
    }

    /**
     * Définit la valeur de la propriété frozen.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFROZEN(String value) {
        this.frozen = value;
    }

    /**
     * Obtient la valeur de la propriété woschedulecomment.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWOSCHEDULECOMMENT() {
        return woschedulecomment;
    }

    /**
     * Définit la valeur de la propriété woschedulecomment.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWOSCHEDULECOMMENT(String value) {
        this.woschedulecomment = value;
    }

    /**
     * Obtient la valeur de la propriété dbsessionid.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getDBSESSIONID() {
        return dbsessionid;
    }

    /**
     * Définit la valeur de la propriété dbsessionid.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setDBSESSIONID(QUANTITY value) {
        this.dbsessionid = value;
    }

    /**
     * Obtient la valeur de la propriété mainresource.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMAINRESOURCE() {
        return mainresource;
    }

    /**
     * Définit la valeur de la propriété mainresource.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMAINRESOURCE(String value) {
        this.mainresource = value;
    }

    /**
     * Obtient la valeur de la propriété recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Définit la valeur de la propriété recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_entities/workorderschedule_002/WorkOrderSchedule.java <==

package net.datastream.schemas.mp_entities.workorderschedule_002;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CREWID_Type;
import net.datastream.schemas.mp_fields.DEPARTMENTID_Type;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.PERSONID_Type;
import net.datastream.schemas.mp_fields.SHIFTID_Type;
import net.datastream.schemas.mp_fields.TIME_Type;
import net.datastream.schemas.mp_fields.TRADEID_Type;
import net.datastream.schemas.mp_fields.WOSCHEDULEID;
import org.openapplications.oagis_segments.DATETIME;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}WOSCHEDULEID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}SCHEDULEDDATE"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}SCHEDULEDHOURS" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ACTUALSTARTTIME" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ACTUALENDTIME" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TRADEID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}DEPARTMENTID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}SHIFTID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}EMPLOYEE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}CREWID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}MAINTENANCEEQUIPMENTID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ENTEREDBY" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}FROZEN" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}WOSCHEDULECOMMENT" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}DBSESSIONID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}MAINRESOURCE" minOccurs="0"/>
 *       </sequence>
 *       <attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "woscheduleid",
    "scheduleddate",
    "scheduledhours",
    "actualstarttime",
    "actualendtime",
    "tradeid",
    "departmentid",
    "shiftid",
    "employee",
    "crewid",
    "maintenanceequipmentid",
    "enteredby",
    "frozen",
    "woschedulecomment",
    "dbsessionid",
    "mainresource"
})
@XmlRootElement(name = "WorkOrderSchedule")
public class WorkOrderSchedule {

    @XmlElement(name = "WOSCHEDULEID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected WOSCHEDULEID woscheduleid;
    @XmlElement(name = "SCHEDULEDDATE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected DATETIME scheduleddate;
    @XmlElement(name = "SCHEDULEDHOURS", namespace = "http://schemas.datastream.net/MP_fields")
    protected Double scheduledhours;
    @XmlElement(name = "ACTUALSTARTTIME", namespace = "http://schemas.datastream.net/MP_fields")
    protected TIME_Type actualstarttime;
    @XmlElement(name = "ACTUALENDTIME", namespace = "http://schemas.datastream.net/MP_fields")
    protected TIME_Type actualendtime;
    @XmlElement(name = "TRADEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected TRADEID_Type tradeid;
    @XmlElement(name = "DEPARTMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected DEPARTMENTID_Type departmentid;
    @XmlElement(name = "SHIFTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected SHIFTID_Type shiftid;
    @XmlElement(name = "EMPLOYEE", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERSONID_Type employee;
    @XmlElement(name = "CREWID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CREWID_Type crewid;
    @XmlElement(name = "MAINTENANCEEQUIPMENTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTID_Type maintenanceequipmentid;
    @XmlElement(name = "ENTEREDBY", namespace = "http://schemas.datastream.net/MP_fields")
    protected String enteredby;
    @XmlElement(name = "FROZEN", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "-")
    protected String frozen;
    @XmlElement(name = "WOSCHEDULECOMMENT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String woschedulecomment;
    @XmlElement(name = "DBSESSIONID", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY dbsessionid;
    @XmlElement(name = "MAINRESOURCE", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String mainresource;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Gets the value of the woscheduleid property.
     * 
     * @return
     *     possible object is
     *     {@link WOSCHEDULEID }
     *     
     */
    public WOSCHEDULEID getWOSCHEDULEID() {
        return woscheduleid;
    }

    /**
     * Sets the value of the woscheduleid property.
     * 
     * @param value
     *     allowed object is
     *     {@link WOSCHEDULEID }
     *     
     */
    public void setWOSCHEDULEID(WOSCHEDULEID value) {
        this.woscheduleid = value;
    }

    /**
     * Gets the value of the scheduleddate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSCHEDULEDDATE() {
        return scheduleddate;
    }

    /**
     * Sets the value of the scheduleddate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSCHEDULEDDATE(DATETIME value) {
        this.scheduleddate = value;
    }

    /**
     * Gets the value of the scheduledhours property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getSCHEDULEDHOURS() {
        return scheduledhours;
    }

    /**
     * Sets the value of the scheduledhours property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setSCHEDULEDHOURS(Double value) {
        this.scheduledhours = value;
    }

    /**
     * Gets the value of the actualstarttime property.
     * 
     * @return
     *     possible object is
     *     {@link TIME_Type }
     *     
     */
    public TIME_Type getACTUALSTARTTIME() {
        return actualstarttime;
    }

    /**
     * Sets the value of the actualstarttime property.
     * 
     * @param value
     *     allowed object is
     *     {@link TIME_Type }
     *     
     */
    public void setACTUALSTARTTIME(TIME_Type value) {
        this.actualstarttime = value;
    }

    /**
     * Gets the value of the actualendtime property.
     * 
     * @return
     *     possible object is
     *     {@link TIME_Type }
     *     
     */
    public TIME_Type getACTUALENDTIME() {
        return actualendtime;
    }

    /**
     * Sets the value of the actualendtime property.
     * 
     * @param value
     *     allowed object is
     *     {@link TIME_Type }
     *     
     */
    public void setACTUALENDTIME(TIME_Type value) {
        this.actualendtime = value;
    }

    /**
     * Gets the value of the tradeid property.
     * 
     * @return
     *     possible object is
     *     {@link TRADEID_Type }
     *     
     */
    public TRADEID_Type getTRADEID() {
        return tradeid;
    }

    /**
     * Sets the value of the tradeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TRADEID_Type }
     *     
     */
    public void setTRADEID(TRADEID_Type value) {
        this.tradeid = value;
    }

    /**
     * Gets the value of the departmentid property.
     * 
     * @return
     *     possible object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public DEPARTMENTID_Type getDEPARTMENTID() {
        return departmentid;
    }

    /**
     * Sets the value of the departmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link DEPARTMENTID_Type }
     *     
     */
    public void setDEPARTMENTID(DEPARTMENTID_Type value) {
        this.departmentid = value;
    }

    /**
     * Gets the value of the shiftid property.
     * 
     * @return
     *     possible object is
     *     {@link SHIFTID_Type }
     *     
     */
    public SHIFTID_Type getSHIFTID() {
        return shiftid;
    }

    /**
     * Sets the value of the shiftid property.
     * 
     * @param value
     *     allowed object is
     *     {@link SHIFTID_Type }
     *     
     */
    public void setSHIFTID(SHIFTID_Type value) {
        this.shiftid = value;
    }

    /**
     * Gets the value of the employee property.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getEMPLOYEE() {
        return employee;
    }

    /**
     * Sets the value of the employee property.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setEMPLOYEE(PERSONID_Type value) {
        this.employee = value;
    }

    /**
     * Gets the value of the crewid property.
     * 
     * @return
     *     possible object is
     *     {@link CREWID_Type }
     *     
     */
    public CREWID_Type getCREWID() {
        return crewid;
    }

    /**
     * Sets the value of the crewid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CREWID_Type }
     *     
     */
    public void setCREWID(CREWID_Type value) {
        this.crewid = value;
    }

    /**
     * Gets the value of the maintenanceequipmentid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getMAINTENANCEEQUIPMENTID() {
        return maintenanceequipmentid;
    }

    /**
     * Sets the value of the maintenanceequipmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setMAINTENANCEEQUIPMENTID(EQUIPMENTID_Type value) {
        this.maintenanceequipmentid = value;
    }

    /**
     * Gets the value of the enteredby property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getENTEREDBY() {
        return enteredby;
    }

    /**
     * Sets the value of the enteredby property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setENTEREDBY(String value) {
        this.enteredby = value;
    }

    /**
     * Gets the value of the frozen property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getFROZEN() {
        return frozen;
    }

    /**
     * Sets the value of the frozen property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setFROZEN(String value) {
        this.frozen = value;
    }

    /**
     * Gets the value of the woschedulecomment property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getWOSCHEDULECOMMENT() {
        return woschedulecomment;
    }

    /**
     * Sets the value of the woschedulecomment property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setWOSCHEDULECOMMENT(String value) {
        this.woschedulecomment = value;
    }

    /**
     * Gets the value of the dbsessionid property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getDBSESSIONID() {
        return dbsessionid;
    }

    /**
     * Sets the value of the dbsessionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setDBSESSIONID(QUANTITY value) {
        this.dbsessionid = value;
    }

    /**
     * Gets the value of the mainresource property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getMAINRESOURCE() {
        return mainresource;
    }

    /**
     * Sets the value of the mainresource property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setMAINRESOURCE(String value) {
        this.mainresource = value;
    }

    /**
     * Gets the value of the recordid property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Sets the value of the recordid property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}
